pub fn decode_protobuf(data: &[u8]) -> Option<Vec<ProtoField>>Expand description
Attempt to decode raw bytes as protobuf wire format fields.
Returns None if the bytes do not look like valid protobuf.
pub fn decode_protobuf(data: &[u8]) -> Option<Vec<ProtoField>>Attempt to decode raw bytes as protobuf wire format fields.
Returns None if the bytes do not look like valid protobuf.