pub struct DebugLayer { /* private fields */ }Expand description
Configuration for the gRPC debug middleware.
Implementations
Sourceimpl DebugLayer
impl DebugLayer
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new DebugLayer with default configuration.
By default, headers and bodies are logged, hex dumps are off.
Sourcepub fn with_config(config: DebugConfig) -> Self
pub fn with_config(config: DebugConfig) -> Self
Create a new DebugLayer with the given configuration.
Sourcepub fn log_headers(self, enabled: bool) -> Self
pub fn log_headers(self, enabled: bool) -> Self
Set whether to log request/response headers.
Sourcepub fn log_bodies(self, enabled: bool) -> Self
pub fn log_bodies(self, enabled: bool) -> Self
Set whether to log request/response bodies.
Sourcepub fn log_response_frames(self, enabled: bool) -> Self
pub fn log_response_frames(self, enabled: bool) -> Self
Set whether to log individual response body frames.
Sourcepub fn max_body_bytes(self, max: usize) -> Self
pub fn max_body_bytes(self, max: usize) -> Self
Set the maximum number of bytes to capture for body inspection.