Module service

Module service 

Tower Service implementation for gRPC request/response interception.

DebugService intercepts every gRPC call, logs request metadata and body contents, forwards to the inner service, and then logs the response.

Structs

DebugService
A Tower service that intercepts and logs gRPC requests and responses.